@@ -60,12 +60,7 @@ impl HostBlock {
     }
 
     pub fn generate_tm_block(chain_id: ChainId, height: u64) -> TmLightBlock {
-        // Sleep is required otherwise the generator produces blocks with the
-        // same timestamp as two block can be generated per second.
-        let ten_millis = core::time::Duration::from_millis(1000);
-        std::thread::sleep(ten_millis);
         let time: Time = OffsetDateTime::now_utc().try_into().unwrap();
-        let time = time.duration_since(Time::unix_epoch()).unwrap().as_secs();
 
         TestgenLightBlock::new_default_with_time_and_chain_id(chain_id.to_string(), time, height)
             .generate()
